# BrIANN
This is a package for developing brain inspired artificial neural networks. 

# Documentation
https://briann.readthedocs.io/en/latest/index.html

# Examples
https://github.com/TimHenry1995/briann/tree/main/experiments
